@@ -112,7 +112,7 @@ public:
 	 * Count the number of linked objects in a list.
 	 * @param root pointer to list we are counting.
 	 */
-	static unsigned count(LinkedObject *root);
+	static unsigned count(const LinkedObject *root);
 
 	/**
 	 * Get member by index.
@@ -507,6 +507,12 @@ protected:
 	 */
 	NamedTree(NamedTree *parent, char *name);
 
+	/**
+	 * Construct a copy of the tree.
+     * @param source object to copy from.
+	 */
+	NamedTree(const NamedTree& source);
+
 	/**
 	 * Delete node in a tree.  If we delete a node, we must delist it from
 	 * it's parent.  We must also delink any child nodes.  This is done by
@@ -821,7 +827,7 @@ protected:
 	 * @param size of key to check or 0 if NULL terminated string.
 	 * @return true if matches key.
 	 */
-	virtual bool compare(unsigned path, caddr_t key, size_t size);
+	virtual bool compare(unsigned path, caddr_t key, size_t size) const;
 	
 public:
 	/**
@@ -851,7 +857,7 @@ public:
 	 * Get next node from single chain.
 	 * @param path to follow.
 	 */
-	MultiMap *next(unsigned path);
+	MultiMap *next(unsigned path) const;
 
 	/**
 	 * Compute binary key index.
@@ -1247,6 +1253,13 @@ public:
 	 */
 	inline treemap(char *name = NULL) : NamedTree(name) {};
 
+	/**
+	 * Construct a copy of the treemap object.
+	 * @param source of copy for new object.
+	 */
+	inline treemap(const treemap& source) : NamedTree(source) 
+		{value = source.value;};
+
 	/**
 	 * Construct a child node on an existing tree.
 	 * @param parent of this node to attach.
