@@ -84,7 +84,7 @@ void DateTime::release(struct tm *dt)
 }
 
 #else
-static Mutex locking;
+static mutex_t lockflag;
 
 struct tm *DateTime::glt(time_t *now)
 {	
@@ -96,11 +96,11 @@ struct tm *DateTime::glt(time_t *now)
 		time(&tmp);
 	}
 
-	locking.acquire();
+	lockflag.acquire();
 	dt = localtime(now);
 	if(dt)
 		return dt;
-	locking.release();
+	lockflag.release();
 	return NULL;
 }
 
@@ -114,28 +114,25 @@ struct tm *DateTime::gmt(time_t *now)
 		time(&tmp);
 	}
 
-	locking.acquire();
+	lockflag.acquire();
 	dt = gmtime(now);
 	if(dt)
 		return dt;
-	locking.release();
+	lockflag.release();
 	return NULL;
 }
 
 void DateTime::release(struct tm *dt)
 {
 	if(dt)
-		locking.release();
+		lockflag.release();
 }
 
 #endif
 
 Date::Date()
 {
-	tm_t *dt = DateTime::glt();
-
-	toJulian(dt->tm_year + 1900, dt->tm_mon + 1, dt->tm_mday);
-	DateTime::release(dt);
+	set();
 }
 
 Date::Date(const Date& copy)
@@ -164,6 +161,14 @@ Date::~Date()
 {
 }
 
+void Date::set()
+{
+	tm_t *dt = DateTime::glt();
+
+	toJulian(dt->tm_year + 1900, dt->tm_mon + 1, dt->tm_mday);
+	DateTime::release(dt);
+}
+
 void Date::set(const char *str, size_t size)
 {
 	tm_t *dt = DateTime::glt();
@@ -436,9 +441,7 @@ void Date::fromJulian(char *buffer) const
 
 Time::Time()
 {
-	tm_t *dt = DateTime::glt();
-	toSeconds(dt->tm_hour, dt->tm_min, dt->tm_sec);
-	DateTime::release(dt);
+	set();
 }
 
 Time::Time(const Time& copy)
@@ -472,6 +475,13 @@ Time::~Time()
 {
 }
 
+void Time::set(void)
+{
+	tm_t *dt = DateTime::glt();
+	toSeconds(dt->tm_hour, dt->tm_min, dt->tm_sec);
+	DateTime::release(dt);
+}
+
 bool Time::isValid(void) const
 {
 	if(seconds == -1)
@@ -739,6 +749,12 @@ DateTime::~DateTime()
 {
 }
 
+void DateTime::set()
+{
+	Date::set();
+	Time::set();
+}
+
 bool DateTime::isValid(void) const
 {
 	return Date::isValid() && Time::isValid();
@@ -789,14 +805,14 @@ DateTime& DateTime::operator=(const DateTime& datetime)
 DateTime& DateTime::operator+=(long value)
 {
 	seconds += value;
-	DateTime::update();
+	update();
 	return *this;
 }
 
 DateTime& DateTime::operator-=(long value)
 {
 	seconds -= value;
-	DateTime::update();
+	update();
 	return *this;
 }
 
@@ -904,14 +920,15 @@ DateTime DateTime::operator-(long value)
 DateTime& DateTime::operator++()
 {
 	++julian;
-	Date::update();
+	update();
 	return *this;
 }
 
+
 DateTime& DateTime::operator--()
 {
 	--julian;
-	Date::update();
+	update();
 	return *this;
 }
 
@@ -927,3 +944,90 @@ Number(str, 10), Date(str, 10)
 DateNumber::~DateNumber()
 {}
 
+void DateNumber::update(void)
+{
+	fromJulian(buffer);
+}
+
+void DateNumber::set(void)
+{
+	Date::set();
+	update();
+}
+
+DateTimeString::DateTimeString(time_t t) :
+DateTime(t)
+{
+	mode = BOTH;
+	DateTimeString::update();
+}
+
+DateTimeString::~DateTimeString()
+{
+}
+
+DateTimeString::DateTimeString(struct tm *dt) :
+DateTime(dt)
+{
+	mode = BOTH;
+	DateTimeString::update();
+}
+
+
+DateTimeString::DateTimeString(const DateTimeString& copy) :
+DateTime(copy)
+{
+	mode = copy.mode;
+	DateTimeString::update();
+}
+
+DateTimeString::DateTimeString(const char *a_str, size_t size) :
+DateTime(a_str, size)
+{
+	mode = BOTH;
+	DateTimeString::update();
+}
+
+
+DateTimeString::DateTimeString(int year, unsigned month, unsigned day,
+		   int hour, int minute, int second) :
+DateTime(year, month, day, hour, minute, second)
+{
+	mode = BOTH;
+	DateTimeString::update();
+}
+
+DateTimeString::DateTimeString(mode_t m) :
+DateTime()
+{
+	mode = m;
+	DateTimeString::update();
+}
+
+void DateTimeString::update(void)
+{
+	DateTime::update();
+	switch(mode) {
+	case BOTH:
+		DateTime::get(buffer);
+		break;
+	case DATE:
+		Date::get(buffer);
+		break;
+	case TIME:
+		Time::get(buffer);
+	}
+}
+
+void DateTimeString::set(mode_t newmode)
+{
+	mode = newmode;
+	update();
+}
+
+void DateTimeString::set(void)
+{
+	DateTime::set();
+	update();
+}
+
